@@ -12,6 +12,7 @@ from .nodes import NodesClient
 from .remote import RemoteClient
 from .snapshot import SnapshotClient
 from .tasks import TasksClient
+from .xpack import XPackClient
 from .utils import query_params, _make_path, SKIP_IN_PATH
 
 logger = logging.getLogger('elasticsearch')
@@ -150,6 +151,23 @@ class Elasticsearch(object):
             ],
             verify_certs=True
         )
+    
+    By default, `JSONSerializer
+    <https://github.com/elastic/elasticsearch-py/blob/master/elasticsearch/serializer.py#L24>`_ 
+    is used to encode all outgoing requests.
+    However, you can implement your own custom serializer::
+    
+        from elasticsearch.serializer import JSONSerializer
+
+        class SetEncoder(JSONSerializer):
+            def default(self, obj):
+                if isinstance(obj, set):
+                    return list(obj)
+                if isinstance(obj, Something):
+                    return 'CustomSomethingRepresentation'
+                return JSONSerializer.default(self, obj)
+        
+        es = Elasticsearch(serializer=SetEncoder())
 
     """
     def __init__(self, hosts=None, transport_class=Transport, **kwargs):
@@ -178,15 +196,16 @@ class Elasticsearch(object):
         self.remote = RemoteClient(self)
         self.snapshot = SnapshotClient(self)
         self.tasks = TasksClient(self)
+        self.xpack = XPackClient(self)
 
     def __repr__(self):
         try:
-            # get a lost of all connections
+            # get a list of all connections
             cons = self.transport.hosts
-            # truncate to 10 if there are too many
+            # truncate to 5 if there are too many
             if len(cons) > 5:
                 cons = cons[:5] + ['...']
-            return '<Elasticsearch(%r)>' % cons
+            return '<{cls}({cons})>'.format(cls=self.__class__.__name__, cons=cons)
         except:
             # probably operating on custom transport and connection_pool, ignore
             return super(Elasticsearch, self).__repr__()
@@ -574,7 +593,7 @@ class Elasticsearch(object):
             choices are: 'open', 'closed', 'none', 'all'
         :arg explain: Specify whether to return detailed information about score
             computation as part of a hit
-        :arg from\_: Starting offset (default: 0)
+        :arg from\\_: Starting offset (default: 0)
         :arg ignore_unavailable: Whether specified concrete indices should be
             ignored when unavailable (missing or closed)
         :arg lenient: Specify whether format-based query failures (such as
@@ -674,7 +693,7 @@ class Elasticsearch(object):
         :arg expand_wildcards: Whether to expand wildcard expression to concrete
             indices that are open, closed or both., default 'open', valid
             choices are: 'open', 'closed', 'none', 'all'
-        :arg from\_: Starting offset (default: 0)
+        :arg from\\_: Starting offset (default: 0)
         :arg ignore_unavailable: Whether specified concrete indices should be
             ignored when unavailable (missing or closed)
         :arg lenient: Specify whether format-based query failures (such as
@@ -810,7 +829,7 @@ class Elasticsearch(object):
         :arg expand_wildcards: Whether to expand wildcard expression to concrete
             indices that are open, closed or both., default 'open', valid
             choices are: 'open', 'closed', 'none', 'all'
-        :arg from\_: Starting offset (default: 0)
+        :arg from\\_: Starting offset (default: 0)
         :arg ignore_unavailable: Whether specified concrete indices should be
             ignored when unavailable (missing or closed)
         :arg lenient: Specify whether format-based query failures (such as
@@ -1047,7 +1066,7 @@ class Elasticsearch(object):
 
     @query_params('allow_no_indices', 'analyze_wildcard', 'analyzer',
         'default_operator', 'df', 'expand_wildcards', 'ignore_unavailable',
-        'lenient', 'min_score', 'preference', 'q', 'routing')
+        'lenient', 'min_score', 'preference', 'q', 'routing', 'terminate_after')
     def count(self, index=None, doc_type=None, body=None, params=None):
         """
         Execute a query and get the number of matches for that query.
